pub trait BoundedIndex<T> {
// Required methods
fn get(self, bounded: &T) -> Result<T, BoundedReaderErr>;
fn clamped_get(self, bounded: &T) -> T;
}Expand description
Trait for types that can be used as sub-ranges of a bounded reader.
pub trait BoundedIndex<T> {
// Required methods
fn get(self, bounded: &T) -> Result<T, BoundedReaderErr>;
fn clamped_get(self, bounded: &T) -> T;
}Trait for types that can be used as sub-ranges of a bounded reader.